Class: DigitalFemsa::BalancesApi
- Inherits:
-
Object
- Object
- DigitalFemsa::BalancesApi
- Defined in:
- lib/digital_femsa/api/balances_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_balance(opts = {}) ⇒ BalanceResponse
Get a company’s balance Retrieves the current balance information for the authenticated company.
-
#get_balance_with_http_info(opts = {}) ⇒ Array<(BalanceResponse, Integer, Hash)>
Get a company's balance Retrieves the current balance information for the authenticated company.
-
#initialize(api_client = ApiClient.default) ⇒ BalancesApi
constructor
A new instance of BalancesApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ BalancesApi
Returns a new instance of BalancesApi.
19 20 21 |
# File 'lib/digital_femsa/api/balances_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/digital_femsa/api/balances_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_balance(opts = {}) ⇒ BalanceResponse
Get a company’s balance Retrieves the current balance information for the authenticated company. Monetary fields are returned as arrays of amounts grouped by currency.
27 28 29 30 |
# File 'lib/digital_femsa/api/balances_api.rb', line 27 def get_balance(opts = {}) data, _status_code, _headers = get_balance_with_http_info(opts) data end |
#get_balance_with_http_info(opts = {}) ⇒ Array<(BalanceResponse, Integer, Hash)>
Get a company's balance Retrieves the current balance information for the authenticated company. Monetary fields are returned as arrays of amounts grouped by currency.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/digital_femsa/api/balances_api.rb', line 37 def get_balance_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BalancesApi.get_balance ...' end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/balance' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'BalanceResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"BalancesApi.get_balance", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BalancesApi#get_balance\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |