Class: DigitalFemsa::ChargesApi
- Inherits:
-
Object
- Object
- DigitalFemsa::ChargesApi
- Defined in:
- lib/digital_femsa/api/charges_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_charges(opts = {}) ⇒ GetChargesResponse
List charges Retrieves a paginated list of charges for the authenticated account.
-
#get_charges_with_http_info(opts = {}) ⇒ Array<(GetChargesResponse, Integer, Hash)>
List charges Retrieves a paginated list of charges for the authenticated account.
-
#initialize(api_client = ApiClient.default) ⇒ ChargesApi
constructor
A new instance of ChargesApi.
-
#orders_create_charge(id, charge_request, opts = {}) ⇒ ChargeOrderResponse
Create a charge for an order Creates a new charge associated with an existing order.
-
#orders_create_charge_with_http_info(id, charge_request, opts = {}) ⇒ Array<(ChargeOrderResponse, Integer, Hash)>
Create a charge for an order Creates a new charge associated with an existing order.
-
#update_charge(id, charge_update_request, opts = {}) ⇒ ChargeResponse
Update a charge Updates an existing charge.
-
#update_charge_with_http_info(id, charge_update_request, opts = {}) ⇒ Array<(ChargeResponse, Integer, Hash)>
Update a charge Updates an existing charge.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ChargesApi
Returns a new instance of ChargesApi.
19 20 21 |
# File 'lib/digital_femsa/api/charges_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/digital_femsa/api/charges_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_charges(opts = {}) ⇒ GetChargesResponse
List charges Retrieves a paginated list of charges for the authenticated account. Use the pagination parameters (‘limit`, `next_page`, `previous_page`) to navigate through results. Use `search` to filter charges (for example by id or reference).
32 33 34 35 |
# File 'lib/digital_femsa/api/charges_api.rb', line 32 def get_charges(opts = {}) data, _status_code, _headers = get_charges_with_http_info(opts) data end |
#get_charges_with_http_info(opts = {}) ⇒ Array<(GetChargesResponse, Integer, Hash)>
List charges Retrieves a paginated list of charges for the authenticated account. Use the pagination parameters (`limit`, `next_page`, `previous_page`) to navigate through results. Use `search` to filter charges (for example by id or reference).
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/digital_femsa/api/charges_api.rb', line 47 def get_charges_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ChargesApi.get_charges ...' end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 250 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling ChargesApi.get_charges, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling ChargesApi.get_charges, must be greater than or equal to 1.' end # resource path local_var_path = '/charges' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'next'] = opts[:'_next'] if !opts[:'_next'].nil? query_params[:'previous'] = opts[:'previous'] if !opts[:'previous'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetChargesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ChargesApi.get_charges", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ChargesApi#get_charges\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#orders_create_charge(id, charge_request, opts = {}) ⇒ ChargeOrderResponse
Create a charge for an order Creates a new charge associated with an existing order. Notes: - The charge is created for the order identified by the path parameter ‘id`. - Depending on the payment method, the charge may be created in a non-final status (for example, pending). - If the order does not meet the required conditions, the API may respond with **428 Precondition Required**.
117 118 119 120 |
# File 'lib/digital_femsa/api/charges_api.rb', line 117 def orders_create_charge(id, charge_request, opts = {}) data, _status_code, _headers = orders_create_charge_with_http_info(id, charge_request, opts) data end |
#orders_create_charge_with_http_info(id, charge_request, opts = {}) ⇒ Array<(ChargeOrderResponse, Integer, Hash)>
Create a charge for an order Creates a new charge associated with an existing order. Notes: - The charge is created for the order identified by the path parameter `id`. - Depending on the payment method, the charge may be created in a non-final status (for example, pending). - If the order does not meet the required conditions, the API may respond with **428 Precondition Required**.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/digital_femsa/api/charges_api.rb', line 130 def orders_create_charge_with_http_info(id, charge_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ChargesApi.orders_create_charge ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ChargesApi.orders_create_charge" end # verify the required parameter 'charge_request' is set if @api_client.config.client_side_validation && charge_request.nil? fail ArgumentError, "Missing the required parameter 'charge_request' when calling ChargesApi.orders_create_charge" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/orders/{id}/charges'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(charge_request) # return_type return_type = opts[:debug_return_type] || 'ChargeOrderResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ChargesApi.orders_create_charge", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ChargesApi#orders_create_charge\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_charge(id, charge_update_request, opts = {}) ⇒ ChargeResponse
Update a charge Updates an existing charge. Only ‘reference_id` can be updated.
201 202 203 204 |
# File 'lib/digital_femsa/api/charges_api.rb', line 201 def update_charge(id, charge_update_request, opts = {}) data, _status_code, _headers = update_charge_with_http_info(id, charge_update_request, opts) data end |
#update_charge_with_http_info(id, charge_update_request, opts = {}) ⇒ Array<(ChargeResponse, Integer, Hash)>
Update a charge Updates an existing charge. Only `reference_id` can be updated.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/digital_femsa/api/charges_api.rb', line 214 def update_charge_with_http_info(id, charge_update_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ChargesApi.update_charge ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ChargesApi.update_charge" end # verify the required parameter 'charge_update_request' is set if @api_client.config.client_side_validation && charge_update_request.nil? fail ArgumentError, "Missing the required parameter 'charge_update_request' when calling ChargesApi.update_charge" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/charges/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(charge_update_request) # return_type return_type = opts[:debug_return_type] || 'ChargeResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ChargesApi.update_charge", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ChargesApi#update_charge\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |