Class: DigitalFemsa::Checkout

Inherits:
Object
  • Object
show all
Defined in:
lib/digital_femsa/models/checkout.rb

Overview

Creates a Payment Link. This is a sub-resource related to an Order template: each time a customer pays using the link, the API will create an Order using ‘order_template`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Checkout

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/digital_femsa/models/checkout.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DigitalFemsa::Checkout` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DigitalFemsa::Checkout`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'recurrent')
    self.recurrent = attributes[:'recurrent']
  else
    self.recurrent = nil
  end

  if attributes.key?(:'payments_limit_count')
    self.payments_limit_count = attributes[:'payments_limit_count']
  end

  if attributes.key?(:'allowed_payment_methods')
    if (value = attributes[:'allowed_payment_methods']).is_a?(Array)
      self.allowed_payment_methods = value
    end
  else
    self.allowed_payment_methods = nil
  end

  if attributes.key?(:'needs_shipping_contact')
    self.needs_shipping_contact = attributes[:'needs_shipping_contact']
  else
    self.needs_shipping_contact = nil
  end

  if attributes.key?(:'starts_at')
    self.starts_at = attributes[:'starts_at']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  else
    self.expires_at = nil
  end

  if attributes.key?(:'can_not_expire')
    self.can_not_expire = attributes[:'can_not_expire']
  end

  if attributes.key?(:'order_template')
    self.order_template = attributes[:'order_template']
  else
    self.order_template = nil
  end
end

Instance Attribute Details

#allowed_payment_methodsObject

Payment methods available in the payment link.



32
33
34
# File 'lib/digital_femsa/models/checkout.rb', line 32

def allowed_payment_methods
  @allowed_payment_methods
end

#can_not_expireObject

If true, the link does not expire.



44
45
46
# File 'lib/digital_femsa/models/checkout.rb', line 44

def can_not_expire
  @can_not_expire
end

#expires_atObject

Expiration time for the link (Unix timestamp in seconds). Valid range is between 2 and 365 days (calculated from the next day of creation at 00:01).



41
42
43
# File 'lib/digital_femsa/models/checkout.rb', line 41

def expires_at
  @expires_at
end

#nameObject

Payment link name.



20
21
22
# File 'lib/digital_femsa/models/checkout.rb', line 20

def name
  @name
end

#needs_shipping_contactObject

This flag allows you to fill in the shipping information at checkout.



35
36
37
# File 'lib/digital_femsa/models/checkout.rb', line 35

def needs_shipping_contact
  @needs_shipping_contact
end

#order_templateObject

Returns the value of attribute order_template.



46
47
48
# File 'lib/digital_femsa/models/checkout.rb', line 46

def order_template
  @order_template
end

#payments_limit_countObject

Required when ‘recurrent` is true. Maximum number of payments allowed through the link.



29
30
31
# File 'lib/digital_femsa/models/checkout.rb', line 29

def payments_limit_count
  @payments_limit_count
end

#recurrentObject

false: single use. true: multiple payments



26
27
28
# File 'lib/digital_femsa/models/checkout.rb', line 26

def recurrent
  @recurrent
end

#starts_atObject

Start time for the link. Unix timestamp in seconds.



38
39
40
# File 'lib/digital_femsa/models/checkout.rb', line 38

def starts_at
  @starts_at
end

#typeObject

Checkout type.



23
24
25
# File 'lib/digital_femsa/models/checkout.rb', line 23

def type
  @type
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/digital_femsa/models/checkout.rb', line 269

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = DigitalFemsa.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/digital_femsa/models/checkout.rb', line 65

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/digital_femsa/models/checkout.rb', line 49

def self.attribute_map
  {
    :'name' => :'name',
    :'type' => :'type',
    :'recurrent' => :'recurrent',
    :'payments_limit_count' => :'payments_limit_count',
    :'allowed_payment_methods' => :'allowed_payment_methods',
    :'needs_shipping_contact' => :'needs_shipping_contact',
    :'starts_at' => :'starts_at',
    :'expires_at' => :'expires_at',
    :'can_not_expire' => :'can_not_expire',
    :'order_template' => :'order_template'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/digital_femsa/models/checkout.rb', line 245

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/digital_femsa/models/checkout.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/digital_femsa/models/checkout.rb', line 70

def self.openapi_types
  {
    :'name' => :'String',
    :'type' => :'String',
    :'recurrent' => :'Boolean',
    :'payments_limit_count' => :'Integer',
    :'allowed_payment_methods' => :'Array<String>',
    :'needs_shipping_contact' => :'Boolean',
    :'starts_at' => :'Integer',
    :'expires_at' => :'Integer',
    :'can_not_expire' => :'Boolean',
    :'order_template' => :'CheckoutOrderTemplate'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/digital_femsa/models/checkout.rb', line 215

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      type == o.type &&
      recurrent == o.recurrent &&
      payments_limit_count == o.payments_limit_count &&
      allowed_payment_methods == o.allowed_payment_methods &&
      needs_shipping_contact == o.needs_shipping_contact &&
      starts_at == o.starts_at &&
      expires_at == o.expires_at &&
      can_not_expire == o.can_not_expire &&
      order_template == o.order_template
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/digital_femsa/models/checkout.rb', line 340

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


232
233
234
# File 'lib/digital_femsa/models/checkout.rb', line 232

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



238
239
240
# File 'lib/digital_femsa/models/checkout.rb', line 238

def hash
  [name, type, recurrent, payments_limit_count, allowed_payment_methods, needs_shipping_contact, starts_at, expires_at, can_not_expire, order_template].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/digital_femsa/models/checkout.rb', line 165

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @recurrent.nil?
    invalid_properties.push('invalid value for "recurrent", recurrent cannot be nil.')
  end

  if @allowed_payment_methods.nil?
    invalid_properties.push('invalid value for "allowed_payment_methods", allowed_payment_methods cannot be nil.')
  end

  if @needs_shipping_contact.nil?
    invalid_properties.push('invalid value for "needs_shipping_contact", needs_shipping_contact cannot be nil.')
  end

  if @expires_at.nil?
    invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.')
  end

  if @order_template.nil?
    invalid_properties.push('invalid value for "order_template", order_template cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



316
317
318
# File 'lib/digital_femsa/models/checkout.rb', line 316

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/digital_femsa/models/checkout.rb', line 322

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



310
311
312
# File 'lib/digital_femsa/models/checkout.rb', line 310

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



201
202
203
204
205
206
207
208
209
210
211
# File 'lib/digital_femsa/models/checkout.rb', line 201

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @type.nil?
  return false if @recurrent.nil?
  return false if @allowed_payment_methods.nil?
  return false if @needs_shipping_contact.nil?
  return false if @expires_at.nil?
  return false if @order_template.nil?
  true
end