Class: DigitalFemsa::OrderResponseCheckout

Inherits:
Object
  • Object
show all
Defined in:
lib/digital_femsa/models/order_response_checkout.rb

Overview

Checkout resource linked to the order. Present only when the order is linked to a checkout (‘channel.checkout_request_id`).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OrderResponseCheckout

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 129

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DigitalFemsa::OrderResponseCheckout` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DigitalFemsa::OrderResponseCheckout`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'allowed_payment_methods')
    if (value = attributes[:'allowed_payment_methods']).is_a?(Array)
      self.allowed_payment_methods = value
    end
  end

  if attributes.key?(:'can_not_expire')
    self.can_not_expire = attributes[:'can_not_expire']
  end

  if attributes.key?(:'emails_sent')
    self.emails_sent = attributes[:'emails_sent']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'failure_url')
    self.failure_url = attributes[:'failure_url']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'is_redirect_on_failure')
    self.is_redirect_on_failure = attributes[:'is_redirect_on_failure']
  end

  if attributes.key?(:'livemode')
    self.livemode = attributes[:'livemode']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'needs_shipping_contact')
    self.needs_shipping_contact = attributes[:'needs_shipping_contact']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'on_demand_enabled')
    self.on_demand_enabled = attributes[:'on_demand_enabled']
  end

  if attributes.key?(:'recurrent')
    self.recurrent = attributes[:'recurrent']
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  end

  if attributes.key?(:'sms_sent')
    self.sms_sent = attributes[:'sms_sent']
  end

  if attributes.key?(:'success_url')
    self.success_url = attributes[:'success_url']
  end

  if attributes.key?(:'starts_at')
    self.starts_at = attributes[:'starts_at']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end
end

Instance Attribute Details

#allowed_payment_methodsObject

Returns the value of attribute allowed_payment_methods.



19
20
21
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 19

def allowed_payment_methods
  @allowed_payment_methods
end

#can_not_expireObject

Returns the value of attribute can_not_expire.



21
22
23
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 21

def can_not_expire
  @can_not_expire
end

#emails_sentObject

Returns the value of attribute emails_sent.



23
24
25
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 23

def emails_sent
  @emails_sent
end

#expires_atObject

Returns the value of attribute expires_at.



25
26
27
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 25

def expires_at
  @expires_at
end

#failure_urlObject

Returns the value of attribute failure_url.



27
28
29
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 27

def failure_url
  @failure_url
end

#idObject

Returns the value of attribute id.



29
30
31
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 29

def id
  @id
end

#is_redirect_on_failureObject

Returns the value of attribute is_redirect_on_failure.



31
32
33
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 31

def is_redirect_on_failure
  @is_redirect_on_failure
end

#livemodeObject

Returns the value of attribute livemode.



33
34
35
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 33

def livemode
  @livemode
end

#metadataObject

Returns the value of attribute metadata.



35
36
37
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 35

def 
  @metadata
end

#nameObject

Returns the value of attribute name.



37
38
39
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 37

def name
  @name
end

#needs_shipping_contactObject

Returns the value of attribute needs_shipping_contact.



39
40
41
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 39

def needs_shipping_contact
  @needs_shipping_contact
end

#objectObject

Returns the value of attribute object.



41
42
43
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 41

def object
  @object
end

#on_demand_enabledObject

Returns the value of attribute on_demand_enabled.



43
44
45
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 43

def on_demand_enabled
  @on_demand_enabled
end

#recurrentObject

Returns the value of attribute recurrent.



45
46
47
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 45

def recurrent
  @recurrent
end

#slugObject

Returns the value of attribute slug.



47
48
49
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 47

def slug
  @slug
end

#sms_sentObject

Returns the value of attribute sms_sent.



49
50
51
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 49

def sms_sent
  @sms_sent
end

#starts_atObject

Returns the value of attribute starts_at.



53
54
55
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 53

def starts_at
  @starts_at
end

#statusObject

Returns the value of attribute status.



55
56
57
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 55

def status
  @status
end

#success_urlObject

Returns the value of attribute success_url.



51
52
53
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 51

def success_url
  @success_url
end

#typeObject

Returns the value of attribute type.



57
58
59
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 57

def type
  @type
end

#urlObject

Returns the value of attribute url.



59
60
61
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 59

def url
  @url
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 332

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = DigitalFemsa.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 62

def self.attribute_map
  {
    :'allowed_payment_methods' => :'allowed_payment_methods',
    :'can_not_expire' => :'can_not_expire',
    :'emails_sent' => :'emails_sent',
    :'expires_at' => :'expires_at',
    :'failure_url' => :'failure_url',
    :'id' => :'id',
    :'is_redirect_on_failure' => :'is_redirect_on_failure',
    :'livemode' => :'livemode',
    :'metadata' => :'metadata',
    :'name' => :'name',
    :'needs_shipping_contact' => :'needs_shipping_contact',
    :'object' => :'object',
    :'on_demand_enabled' => :'on_demand_enabled',
    :'recurrent' => :'recurrent',
    :'slug' => :'slug',
    :'sms_sent' => :'sms_sent',
    :'success_url' => :'success_url',
    :'starts_at' => :'starts_at',
    :'status' => :'status',
    :'type' => :'type',
    :'url' => :'url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 308

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



121
122
123
124
125
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 121

def self.openapi_nullable
  Set.new([
    :'on_demand_enabled',
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 94

def self.openapi_types
  {
    :'allowed_payment_methods' => :'Array<String>',
    :'can_not_expire' => :'Boolean',
    :'emails_sent' => :'Integer',
    :'expires_at' => :'Integer',
    :'failure_url' => :'String',
    :'id' => :'String',
    :'is_redirect_on_failure' => :'Boolean',
    :'livemode' => :'Boolean',
    :'metadata' => :'Hash<String, Object>',
    :'name' => :'String',
    :'needs_shipping_contact' => :'Boolean',
    :'object' => :'String',
    :'on_demand_enabled' => :'Boolean',
    :'recurrent' => :'Boolean',
    :'slug' => :'String',
    :'sms_sent' => :'Integer',
    :'success_url' => :'String',
    :'starts_at' => :'Integer',
    :'status' => :'String',
    :'type' => :'String',
    :'url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 267

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      allowed_payment_methods == o.allowed_payment_methods &&
      can_not_expire == o.can_not_expire &&
      emails_sent == o.emails_sent &&
      expires_at == o.expires_at &&
      failure_url == o.failure_url &&
      id == o.id &&
      is_redirect_on_failure == o.is_redirect_on_failure &&
      livemode == o.livemode &&
       == o. &&
      name == o.name &&
      needs_shipping_contact == o.needs_shipping_contact &&
      object == o.object &&
      on_demand_enabled == o.on_demand_enabled &&
      recurrent == o.recurrent &&
      slug == o.slug &&
      sms_sent == o.sms_sent &&
      success_url == o.success_url &&
      starts_at == o.starts_at &&
      status == o.status &&
      type == o.type &&
      url == o.url
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



403
404
405
406
407
408
409
410
411
412
413
414
415
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 403

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


295
296
297
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 295

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



301
302
303
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 301

def hash
  [allowed_payment_methods, can_not_expire, emails_sent, expires_at, failure_url, id, is_redirect_on_failure, livemode, , name, needs_shipping_contact, object, on_demand_enabled, recurrent, slug, sms_sent, success_url, starts_at, status, type, url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



233
234
235
236
237
238
239
240
241
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 233

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@metadata.nil? && @metadata.length > 100
    invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



379
380
381
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 379

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 385

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



373
374
375
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 373

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



245
246
247
248
249
# File 'lib/digital_femsa/models/order_response_checkout.rb', line 245

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@metadata.nil? && @metadata.length > 100
  true
end