Class: DigitalFemsa::OrderResponseCustomerInfo
- Inherits:
-
Object
- Object
- DigitalFemsa::OrderResponseCustomerInfo
- Defined in:
- lib/digital_femsa/models/order_response_customer_info.rb
Overview
Customer information associated with the order.
Instance Attribute Summary collapse
-
#corporate ⇒ Object
Returns the value of attribute corporate.
-
#customer_custom_reference ⇒ Object
Custom reference.
-
#customer_id ⇒ Object
Returns the value of attribute customer_id.
-
#email ⇒ Object
Returns the value of attribute email.
-
#name ⇒ Object
Returns the value of attribute name.
-
#object ⇒ Object
Returns the value of attribute object.
-
#phone ⇒ Object
Returns the value of attribute phone.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrderResponseCustomerInfo
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ OrderResponseCustomerInfo
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DigitalFemsa::OrderResponseCustomerInfo` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DigitalFemsa::OrderResponseCustomerInfo`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'customer_custom_reference') self.customer_custom_reference = attributes[:'customer_custom_reference'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'corporate') self.corporate = attributes[:'corporate'] else self.corporate = false end if attributes.key?(:'object') self.object = attributes[:'object'] end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end end |
Instance Attribute Details
#corporate ⇒ Object
Returns the value of attribute corporate.
28 29 30 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 28 def corporate @corporate end |
#customer_custom_reference ⇒ Object
Custom reference
20 21 22 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 20 def customer_custom_reference @customer_custom_reference end |
#customer_id ⇒ Object
Returns the value of attribute customer_id.
32 33 34 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 32 def customer_id @customer_id end |
#email ⇒ Object
Returns the value of attribute email.
24 25 26 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 24 def email @email end |
#name ⇒ Object
Returns the value of attribute name.
22 23 24 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 22 def name @name end |
#object ⇒ Object
Returns the value of attribute object.
30 31 32 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 30 def object @object end |
#phone ⇒ Object
Returns the value of attribute phone.
26 27 28 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 26 def phone @phone end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 194 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = DigitalFemsa.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 48 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 35 def self.attribute_map { :'customer_custom_reference' => :'customer_custom_reference', :'name' => :'name', :'email' => :'email', :'phone' => :'phone', :'corporate' => :'corporate', :'object' => :'object', :'customer_id' => :'customer_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 170 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
73 74 75 76 77 78 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 73 def self.openapi_all_of [ :'CustomerInfoJustCustomerIdResponse', :'OrderCustomerInfoResponse' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 70 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 66 def self.openapi_nullable Set.new([ :'customer_custom_reference', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 53 def self.openapi_types { :'customer_custom_reference' => :'String', :'name' => :'String', :'email' => :'String', :'phone' => :'String', :'corporate' => :'Boolean', :'object' => :'String', :'customer_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 143 def ==(o) return true if self.equal?(o) self.class == o.class && customer_custom_reference == o.customer_custom_reference && name == o.name && email == o.email && phone == o.phone && corporate == o.corporate && object == o.object && customer_id == o.customer_id end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 265 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
157 158 159 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 157 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
163 164 165 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 163 def hash [customer_custom_reference, name, email, phone, corporate, object, customer_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
128 129 130 131 132 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 128 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
241 242 243 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 241 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 247 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
235 236 237 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 235 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
136 137 138 139 |
# File 'lib/digital_femsa/models/order_response_customer_info.rb', line 136 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |