Class: DigitalFemsa::OrdersApi
- Inherits:
-
Object
- Object
- DigitalFemsa::OrdersApi
- Defined in:
- lib/digital_femsa/api/orders_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#cancel_order(id, opts = {}) ⇒ OrderResponse
Cancel Order Cancels an existing order.
-
#cancel_order_with_http_info(id, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Cancel Order Cancels an existing order.
-
#create_order(order_request, opts = {}) ⇒ OrderResponse
Create order Creates a new order (products + amounts + customer data).
-
#create_order_with_http_info(order_request, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Create order Creates a new order (products + amounts + customer data).
-
#get_order_by_id(id, opts = {}) ⇒ OrderResponse
Get Order Returns the full details of an Order by its ID.
-
#get_order_by_id_with_http_info(id, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Get Order Returns the full details of an Order by its ID.
-
#get_orders(opts = {}) ⇒ GetOrdersResponse
Get a list of Orders Returns a paginated list of orders created in your account.
-
#get_orders_with_http_info(opts = {}) ⇒ Array<(GetOrdersResponse, Integer, Hash)>
Get a list of Orders Returns a paginated list of orders created in your account.
-
#initialize(api_client = ApiClient.default) ⇒ OrdersApi
constructor
A new instance of OrdersApi.
-
#order_cancel_refund(id, refund_id, opts = {}) ⇒ OrderResponse
Cancel Refund Cancels a refund previously created for an order.
-
#order_cancel_refund_with_http_info(id, refund_id, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Cancel Refund Cancels a refund previously created for an order.
-
#order_refund(id, order_refund_request, opts = {}) ⇒ OrderResponse
Refund Order Creates a refund for an order.
-
#order_refund_with_http_info(id, order_refund_request, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Refund Order Creates a refund for an order.
-
#orders_create_capture(id, opts = {}) ⇒ OrderResponse
Capture Order Captures (finalizes) an order that has been previously authorized.
-
#orders_create_capture_with_http_info(id, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Capture Order Captures (finalizes) an order that has been previously authorized.
-
#update_order(id, order_update_request, opts = {}) ⇒ OrderResponse
Update order Updates an existing order by its ID.
-
#update_order_with_http_info(id, order_update_request, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Update order Updates an existing order by its ID.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/digital_femsa/api/orders_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#cancel_order(id, opts = {}) ⇒ OrderResponse
Cancel Order Cancels an existing order. This operation marks the order as cancelled and prevents further processing depending on its current state. If the order cannot be cancelled (for example, due to its status or related charge constraints), the API returns an error response.
29 30 31 32 |
# File 'lib/digital_femsa/api/orders_api.rb', line 29 def cancel_order(id, opts = {}) data, _status_code, _headers = cancel_order_with_http_info(id, opts) data end |
#cancel_order_with_http_info(id, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Cancel Order Cancels an existing order. This operation marks the order as cancelled and prevents further processing depending on its current state. If the order cannot be cancelled (for example, due to its status or related charge constraints), the API returns an error response.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/digital_femsa/api/orders_api.rb', line 41 def cancel_order_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.cancel_order ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling OrdersApi.cancel_order" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/orders/{id}/cancel'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'OrderResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrdersApi.cancel_order", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#cancel_order\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_order(order_request, opts = {}) ⇒ OrderResponse
Create order Creates a new order (products + amounts + customer data). Minimum required fields: - ‘currency` - `line_items` - `customer_info` About `customer_info`: - You can reference an existing customer using `customer_info.customer_id`, or - You can provide customer details at minimum `customer_info.name` and `customer_info.email` to create the order with customer context. How to create the order: - Create an order only (no payment): send only the order data. - Create an order and create the first payment charge: include `charges`. - Create an order with a checkout configuration (for a hosted payment flow): include `checkout`. Important rules: - You cannot send `charges` and `checkout` in the same request (they are mutually exclusive). - If you send `shipping_contact_id` and/or `fiscal_entity_id`, you must also send `customer_info.customer_id` so the API can validate those IDs against that customer.
102 103 104 105 |
# File 'lib/digital_femsa/api/orders_api.rb', line 102 def create_order(order_request, opts = {}) data, _status_code, _headers = create_order_with_http_info(order_request, opts) data end |
#create_order_with_http_info(order_request, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Create order Creates a new order (products + amounts + customer data). Minimum required fields: - `currency` - `line_items` - `customer_info` About `customer_info`: - You can reference an existing customer using `customer_info.customer_id`, or - You can provide customer details at minimum `customer_info.name` and `customer_info.email` to create the order with customer context. How to create the order: - Create an order only (no payment): send only the order data. - Create an order and create the first payment charge: include `charges`. - Create an order with a checkout configuration (for a hosted payment flow): include `checkout`. Important rules: - You cannot send `charges` and `checkout` in the same request (they are mutually exclusive). - If you send `shipping_contact_id` and/or `fiscal_entity_id`, you must also send `customer_info.customer_id` so the API can validate those IDs against that customer.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/digital_femsa/api/orders_api.rb', line 114 def create_order_with_http_info(order_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.create_order ...' end # verify the required parameter 'order_request' is set if @api_client.config.client_side_validation && order_request.nil? fail ArgumentError, "Missing the required parameter 'order_request' when calling OrdersApi.create_order" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/orders' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(order_request) # return_type return_type = opts[:debug_return_type] || 'OrderResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrdersApi.create_order", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#create_order\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_order_by_id(id, opts = {}) ⇒ OrderResponse
Get Order Returns the full details of an Order by its ID. The response follows the standard Order representation, including nested previews (for example ‘charges`, `line_items`, `shipping_lines`, `tax_lines`, and `discount_lines`) when available.
180 181 182 183 |
# File 'lib/digital_femsa/api/orders_api.rb', line 180 def get_order_by_id(id, opts = {}) data, _status_code, _headers = get_order_by_id_with_http_info(id, opts) data end |
#get_order_by_id_with_http_info(id, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Get Order Returns the full details of an Order by its ID. The response follows the standard Order representation, including nested previews (for example `charges`, `line_items`, `shipping_lines`, `tax_lines`, and `discount_lines`) when available.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/digital_femsa/api/orders_api.rb', line 192 def get_order_by_id_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.get_order_by_id ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling OrdersApi.get_order_by_id" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/orders/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'OrderResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrdersApi.get_order_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#get_order_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_orders(opts = {}) ⇒ GetOrdersResponse
Get a list of Orders Returns a paginated list of orders created in your account. Use pagination parameters to navigate through results, and ‘search` to filter by supported criteria.
256 257 258 259 |
# File 'lib/digital_femsa/api/orders_api.rb', line 256 def get_orders(opts = {}) data, _status_code, _headers = get_orders_with_http_info(opts) data end |
#get_orders_with_http_info(opts = {}) ⇒ Array<(GetOrdersResponse, Integer, Hash)>
Get a list of Orders Returns a paginated list of orders created in your account. Use pagination parameters to navigate through results, and `search` to filter by supported criteria.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/digital_femsa/api/orders_api.rb', line 271 def get_orders_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.get_orders ...' end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 250 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling OrdersApi.get_orders, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling OrdersApi.get_orders, must be greater than or equal to 1.' end # resource path local_var_path = '/orders' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'next'] = opts[:'_next'] if !opts[:'_next'].nil? query_params[:'previous'] = opts[:'previous'] if !opts[:'previous'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetOrdersResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrdersApi.get_orders", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#get_orders\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#order_cancel_refund(id, refund_id, opts = {}) ⇒ OrderResponse
Cancel Refund Cancels a refund previously created for an order. This operation is only available when the refund is still cancellable according to its current status and the payment method rules. If the refund cannot be cancelled, the API returns an error response.
341 342 343 344 |
# File 'lib/digital_femsa/api/orders_api.rb', line 341 def order_cancel_refund(id, refund_id, opts = {}) data, _status_code, _headers = order_cancel_refund_with_http_info(id, refund_id, opts) data end |
#order_cancel_refund_with_http_info(id, refund_id, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Cancel Refund Cancels a refund previously created for an order. This operation is only available when the refund is still cancellable according to its current status and the payment method rules. If the refund cannot be cancelled, the API returns an error response.
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 |
# File 'lib/digital_femsa/api/orders_api.rb', line 354 def order_cancel_refund_with_http_info(id, refund_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.order_cancel_refund ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling OrdersApi.order_cancel_refund" end # verify the required parameter 'refund_id' is set if @api_client.config.client_side_validation && refund_id.nil? fail ArgumentError, "Missing the required parameter 'refund_id' when calling OrdersApi.order_cancel_refund" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/orders/{id}/refunds/{refund_id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)).sub('{' + 'refund_id' + '}', CGI.escape(refund_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'OrderResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrdersApi.order_cancel_refund", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#order_cancel_refund\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#order_refund(id, order_refund_request, opts = {}) ⇒ OrderResponse
Refund Order Creates a refund for an order. This operation is used to refund a previously paid order (fully or partially, depending on the request body). The API will validate the order and its related charges before processing the refund. If the refund cannot be created due to business rules or state, an error response is returned.
420 421 422 423 |
# File 'lib/digital_femsa/api/orders_api.rb', line 420 def order_refund(id, order_refund_request, opts = {}) data, _status_code, _headers = order_refund_with_http_info(id, order_refund_request, opts) data end |
#order_refund_with_http_info(id, order_refund_request, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Refund Order Creates a refund for an order. This operation is used to refund a previously paid order (fully or partially, depending on the request body). The API will validate the order and its related charges before processing the refund. If the refund cannot be created due to business rules or state, an error response is returned.
433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 |
# File 'lib/digital_femsa/api/orders_api.rb', line 433 def order_refund_with_http_info(id, order_refund_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.order_refund ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling OrdersApi.order_refund" end # verify the required parameter 'order_refund_request' is set if @api_client.config.client_side_validation && order_refund_request.nil? fail ArgumentError, "Missing the required parameter 'order_refund_request' when calling OrdersApi.order_refund" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/orders/{id}/refunds'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(order_refund_request) # return_type return_type = opts[:debug_return_type] || 'OrderResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrdersApi.order_refund", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#order_refund\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#orders_create_capture(id, opts = {}) ⇒ OrderResponse
Capture Order Captures (finalizes) an order that has been previously authorized. Use this endpoint to capture a specific amount. The captured amount must be greater than 0 and must comply with the order and charge constraints enforced by the API.
504 505 506 507 |
# File 'lib/digital_femsa/api/orders_api.rb', line 504 def orders_create_capture(id, opts = {}) data, _status_code, _headers = orders_create_capture_with_http_info(id, opts) data end |
#orders_create_capture_with_http_info(id, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Capture Order Captures (finalizes) an order that has been previously authorized. Use this endpoint to capture a specific amount. The captured amount must be greater than 0 and must comply with the order and charge constraints enforced by the API.
517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 |
# File 'lib/digital_femsa/api/orders_api.rb', line 517 def orders_create_capture_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.orders_create_capture ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling OrdersApi.orders_create_capture" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/orders/{id}/capture'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'order_capture_request']) # return_type return_type = opts[:debug_return_type] || 'OrderResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrdersApi.orders_create_capture", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#orders_create_capture\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_order(id, order_update_request, opts = {}) ⇒ OrderResponse
Update order Updates an existing order by its ID. Orders are the central resource in the API. Updating an order may also update related order sub-resources when they are included in the request payload, according to server-side validations. Only fields supported by the API can be modified.
583 584 585 586 |
# File 'lib/digital_femsa/api/orders_api.rb', line 583 def update_order(id, order_update_request, opts = {}) data, _status_code, _headers = update_order_with_http_info(id, order_update_request, opts) data end |
#update_order_with_http_info(id, order_update_request, opts = {}) ⇒ Array<(OrderResponse, Integer, Hash)>
Update order Updates an existing order by its ID. Orders are the central resource in the API. Updating an order may also update related order sub-resources when they are included in the request payload, according to server-side validations. Only fields supported by the API can be modified.
595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 |
# File 'lib/digital_femsa/api/orders_api.rb', line 595 def update_order_with_http_info(id, order_update_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrdersApi.update_order ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling OrdersApi.update_order" end # verify the required parameter 'order_update_request' is set if @api_client.config.client_side_validation && order_update_request.nil? fail ArgumentError, "Missing the required parameter 'order_update_request' when calling OrdersApi.update_order" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/orders/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(order_update_request) # return_type return_type = opts[:debug_return_type] || 'OrderResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"OrdersApi.update_order", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrdersApi#update_order\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |