Class: DigitalFemsa::PaymentLinkApi
- Inherits:
-
Object
- Object
- DigitalFemsa::PaymentLinkApi
- Defined in:
- lib/digital_femsa/api/payment_link_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#cancel_checkout(id, opts = {}) ⇒ CheckoutResponse
Cancel Payment Link Cancels an existing payment link.
-
#cancel_checkout_with_http_info(id, opts = {}) ⇒ Array<(CheckoutResponse, Integer, Hash)>
Cancel Payment Link Cancels an existing payment link.
-
#create_checkout(checkout, opts = {}) ⇒ CheckoutResponse
Create Payment Link Creates a Payment Link: a shareable URL that lets your customer pay without you building a custom checkout.
-
#create_checkout_with_http_info(checkout, opts = {}) ⇒ Array<(CheckoutResponse, Integer, Hash)>
Create Payment Link Creates a Payment Link: a shareable URL that lets your customer pay without you building a custom checkout.
-
#email_checkout(id, email_checkout_request, opts = {}) ⇒ CheckoutResponse
Send an email.
-
#email_checkout_with_http_info(id, email_checkout_request, opts = {}) ⇒ Array<(CheckoutResponse, Integer, Hash)>
Send an email.
-
#get_checkout(id, opts = {}) ⇒ CheckoutResponse
Get a payment link by ID Retrieves the details of a checkout by its ID.
-
#get_checkout_with_http_info(id, opts = {}) ⇒ Array<(CheckoutResponse, Integer, Hash)>
Get a payment link by ID Retrieves the details of a checkout by its ID.
-
#get_checkouts(opts = {}) ⇒ CheckoutsResponse
Get a list of payment links Returns a paginated list of payment links created by the merchant.
-
#get_checkouts_with_http_info(opts = {}) ⇒ Array<(CheckoutsResponse, Integer, Hash)>
Get a list of payment links Returns a paginated list of payment links created by the merchant.
-
#initialize(api_client = ApiClient.default) ⇒ PaymentLinkApi
constructor
A new instance of PaymentLinkApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PaymentLinkApi
Returns a new instance of PaymentLinkApi.
19 20 21 |
# File 'lib/digital_femsa/api/payment_link_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/digital_femsa/api/payment_link_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#cancel_checkout(id, opts = {}) ⇒ CheckoutResponse
Cancel Payment Link Cancels an existing payment link. After cancellation, the link can no longer be used to generate new payments. This operation is idempotent: cancelling an already cancelled payment link returns the current resource representation.
29 30 31 32 |
# File 'lib/digital_femsa/api/payment_link_api.rb', line 29 def cancel_checkout(id, opts = {}) data, _status_code, _headers = cancel_checkout_with_http_info(id, opts) data end |
#cancel_checkout_with_http_info(id, opts = {}) ⇒ Array<(CheckoutResponse, Integer, Hash)>
Cancel Payment Link Cancels an existing payment link. After cancellation, the link can no longer be used to generate new payments. This operation is idempotent: cancelling an already cancelled payment link returns the current resource representation.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/digital_femsa/api/payment_link_api.rb', line 41 def cancel_checkout_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PaymentLinkApi.cancel_checkout ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling PaymentLinkApi.cancel_checkout" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/checkouts/{id}/cancel'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CheckoutResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PaymentLinkApi.cancel_checkout", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PaymentLinkApi#cancel_checkout\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_checkout(checkout, opts = {}) ⇒ CheckoutResponse
Create Payment Link Creates a Payment Link: a shareable URL that lets your customer pay without you building a custom checkout. Configure the link type, allowed payment methods, and expiration. The request also includes an order_template (currency and line items) used to generate an Order when the customer completes a payment. Use recurrent=false for a single-use link, or recurrent=true to allow multiple payments (limited by payments_limit_count).
102 103 104 105 |
# File 'lib/digital_femsa/api/payment_link_api.rb', line 102 def create_checkout(checkout, opts = {}) data, _status_code, _headers = create_checkout_with_http_info(checkout, opts) data end |
#create_checkout_with_http_info(checkout, opts = {}) ⇒ Array<(CheckoutResponse, Integer, Hash)>
Create Payment Link Creates a Payment Link: a shareable URL that lets your customer pay without you building a custom checkout. Configure the link type, allowed payment methods, and expiration. The request also includes an order_template (currency and line items) used to generate an Order when the customer completes a payment. Use recurrent=false for a single-use link, or recurrent=true to allow multiple payments (limited by payments_limit_count).
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/digital_femsa/api/payment_link_api.rb', line 114 def create_checkout_with_http_info(checkout, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PaymentLinkApi.create_checkout ...' end # verify the required parameter 'checkout' is set if @api_client.config.client_side_validation && checkout.nil? fail ArgumentError, "Missing the required parameter 'checkout' when calling PaymentLinkApi.create_checkout" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/checkouts' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(checkout) # return_type return_type = opts[:debug_return_type] || 'CheckoutResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PaymentLinkApi.create_checkout", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PaymentLinkApi#create_checkout\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#email_checkout(id, email_checkout_request, opts = {}) ⇒ CheckoutResponse
Send an email
180 181 182 183 |
# File 'lib/digital_femsa/api/payment_link_api.rb', line 180 def email_checkout(id, email_checkout_request, opts = {}) data, _status_code, _headers = email_checkout_with_http_info(id, email_checkout_request, opts) data end |
#email_checkout_with_http_info(id, email_checkout_request, opts = {}) ⇒ Array<(CheckoutResponse, Integer, Hash)>
Send an email
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/digital_femsa/api/payment_link_api.rb', line 192 def email_checkout_with_http_info(id, email_checkout_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PaymentLinkApi.email_checkout ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling PaymentLinkApi.email_checkout" end # verify the required parameter 'email_checkout_request' is set if @api_client.config.client_side_validation && email_checkout_request.nil? fail ArgumentError, "Missing the required parameter 'email_checkout_request' when calling PaymentLinkApi.email_checkout" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/checkouts/{id}/email'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(email_checkout_request) # return_type return_type = opts[:debug_return_type] || 'CheckoutResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PaymentLinkApi.email_checkout", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PaymentLinkApi#email_checkout\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_checkout(id, opts = {}) ⇒ CheckoutResponse
Get a payment link by ID Retrieves the details of a checkout by its ID.
262 263 264 265 |
# File 'lib/digital_femsa/api/payment_link_api.rb', line 262 def get_checkout(id, opts = {}) data, _status_code, _headers = get_checkout_with_http_info(id, opts) data end |
#get_checkout_with_http_info(id, opts = {}) ⇒ Array<(CheckoutResponse, Integer, Hash)>
Get a payment link by ID Retrieves the details of a checkout by its ID.
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/digital_femsa/api/payment_link_api.rb', line 274 def get_checkout_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PaymentLinkApi.get_checkout ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling PaymentLinkApi.get_checkout" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/checkouts/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CheckoutResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PaymentLinkApi.get_checkout", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PaymentLinkApi#get_checkout\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_checkouts(opts = {}) ⇒ CheckoutsResponse
Get a list of payment links Returns a paginated list of payment links created by the merchant. Results can be navigated using the pagination parameters.
338 339 340 341 |
# File 'lib/digital_femsa/api/payment_link_api.rb', line 338 def get_checkouts(opts = {}) data, _status_code, _headers = get_checkouts_with_http_info(opts) data end |
#get_checkouts_with_http_info(opts = {}) ⇒ Array<(CheckoutsResponse, Integer, Hash)>
Get a list of payment links Returns a paginated list of payment links created by the merchant. Results can be navigated using the pagination parameters.
353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/digital_femsa/api/payment_link_api.rb', line 353 def get_checkouts_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PaymentLinkApi.get_checkouts ...' end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 250 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling PaymentLinkApi.get_checkouts, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling PaymentLinkApi.get_checkouts, must be greater than or equal to 1.' end # resource path local_var_path = '/checkouts' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'next'] = opts[:'_next'] if !opts[:'_next'].nil? query_params[:'previous'] = opts[:'previous'] if !opts[:'previous'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CheckoutsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PaymentLinkApi.get_checkouts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PaymentLinkApi#get_checkouts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |