Class: DigitalFemsa::ProductDataResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/digital_femsa/models/product_data_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ProductDataResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/digital_femsa/models/product_data_response.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DigitalFemsa::ProductDataResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DigitalFemsa::ProductDataResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'unit_price')
    self.unit_price = attributes[:'unit_price']
  else
    self.unit_price = nil
  end

  if attributes.key?(:'quantity')
    self.quantity = attributes[:'quantity']
  else
    self.quantity = nil
  end

  if attributes.key?(:'sku')
    self.sku = attributes[:'sku']
  end

  if attributes.key?(:'brand')
    self.brand = attributes[:'brand']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'parent_id')
    self.parent_id = attributes[:'parent_id']
  end
end

Instance Attribute Details

#brandObject

The brand of the item.



31
32
33
# File 'lib/digital_femsa/models/product_data_response.rb', line 31

def brand
  @brand
end

#descriptionObject

Short description of the item



34
35
36
# File 'lib/digital_femsa/models/product_data_response.rb', line 34

def description
  @description
end

#idObject

Returns the value of attribute id.



42
43
44
# File 'lib/digital_femsa/models/product_data_response.rb', line 42

def id
  @id
end

#metadataObject

Arbitrary key-value data for your internal use. Keys should be strings; values can be any JSON value.



40
41
42
# File 'lib/digital_femsa/models/product_data_response.rb', line 40

def 
  @metadata
end

#nameObject

The name of the item. It will be displayed in the order.



19
20
21
# File 'lib/digital_femsa/models/product_data_response.rb', line 19

def name
  @name
end

#objectObject

Returns the value of attribute object.



44
45
46
# File 'lib/digital_femsa/models/product_data_response.rb', line 44

def object
  @object
end

#parent_idObject

Returns the value of attribute parent_id.



46
47
48
# File 'lib/digital_femsa/models/product_data_response.rb', line 46

def parent_id
  @parent_id
end

#quantityObject

The quantity of the item in the order.



25
26
27
# File 'lib/digital_femsa/models/product_data_response.rb', line 25

def quantity
  @quantity
end

#skuObject

The stock keeping unit for the item. It is used to identify the item in the order.



28
29
30
# File 'lib/digital_femsa/models/product_data_response.rb', line 28

def sku
  @sku
end

#tagsObject

List of tags for the item. It is used to identify the item in the order.



37
38
39
# File 'lib/digital_femsa/models/product_data_response.rb', line 37

def tags
  @tags
end

#unit_priceObject

The price of the item in cents.



22
23
24
# File 'lib/digital_femsa/models/product_data_response.rb', line 22

def unit_price
  @unit_price
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/digital_femsa/models/product_data_response.rb', line 352

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = DigitalFemsa.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/digital_femsa/models/product_data_response.rb', line 66

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/digital_femsa/models/product_data_response.rb', line 49

def self.attribute_map
  {
    :'name' => :'name',
    :'unit_price' => :'unit_price',
    :'quantity' => :'quantity',
    :'sku' => :'sku',
    :'brand' => :'brand',
    :'description' => :'description',
    :'tags' => :'tags',
    :'metadata' => :'metadata',
    :'id' => :'id',
    :'object' => :'object',
    :'parent_id' => :'parent_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/digital_femsa/models/product_data_response.rb', line 328

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



94
95
96
97
98
# File 'lib/digital_femsa/models/product_data_response.rb', line 94

def self.openapi_all_of
  [
  :'Product'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/digital_femsa/models/product_data_response.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/digital_femsa/models/product_data_response.rb', line 71

def self.openapi_types
  {
    :'name' => :'String',
    :'unit_price' => :'Integer',
    :'quantity' => :'Integer',
    :'sku' => :'String',
    :'brand' => :'String',
    :'description' => :'String',
    :'tags' => :'Array<String>',
    :'metadata' => :'Hash<String, Object>',
    :'id' => :'String',
    :'object' => :'String',
    :'parent_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/digital_femsa/models/product_data_response.rb', line 297

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      unit_price == o.unit_price &&
      quantity == o.quantity &&
      sku == o.sku &&
      brand == o.brand &&
      description == o.description &&
      tags == o.tags &&
       == o. &&
      id == o.id &&
      object == o.object &&
      parent_id == o.parent_id
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'lib/digital_femsa/models/product_data_response.rb', line 423

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


315
316
317
# File 'lib/digital_femsa/models/product_data_response.rb', line 315

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



321
322
323
# File 'lib/digital_femsa/models/product_data_response.rb', line 321

def hash
  [name, unit_price, quantity, sku, brand, description, tags, , id, object, parent_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/digital_femsa/models/product_data_response.rb', line 172

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @unit_price.nil?
    invalid_properties.push('invalid value for "unit_price", unit_price cannot be nil.')
  end

  if @unit_price < 0
    invalid_properties.push('invalid value for "unit_price", must be greater than or equal to 0.')
  end

  if @quantity.nil?
    invalid_properties.push('invalid value for "quantity", quantity cannot be nil.')
  end

  if @quantity < 1
    invalid_properties.push('invalid value for "quantity", must be greater than or equal to 1.')
  end

  if !@description.nil? && @description.to_s.length > 250
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 250.')
  end

  if !@tags.nil? && @tags.length < 1
    invalid_properties.push('invalid value for "tags", number of items must be greater than or equal to 1.')
  end

  if !@metadata.nil? && @metadata.length > 100
    invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



399
400
401
# File 'lib/digital_femsa/models/product_data_response.rb', line 399

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/digital_femsa/models/product_data_response.rb', line 405

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



393
394
395
# File 'lib/digital_femsa/models/product_data_response.rb', line 393

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/digital_femsa/models/product_data_response.rb', line 212

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @unit_price.nil?
  return false if @unit_price < 0
  return false if @quantity.nil?
  return false if @quantity < 1
  return false if !@description.nil? && @description.to_s.length > 250
  return false if !@tags.nil? && @tags.length < 1
  return false if !@metadata.nil? && @metadata.length > 100
  true
end