Class: DigitalFemsa::TransfersApi
- Inherits:
-
Object
- Object
- DigitalFemsa::TransfersApi
- Defined in:
- lib/digital_femsa/api/transfers_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_transfer(id, opts = {}) ⇒ TransferResponse
Get transfer Retrieves the details of a transfer by its ID.
-
#get_transfer_with_http_info(id, opts = {}) ⇒ Array<(TransferResponse, Integer, Hash)>
Get transfer Retrieves the details of a transfer by its ID.
-
#get_transfers(opts = {}) ⇒ GetTransfersResponse
List transfers Returns a paginated list of transfers (payouts/dispersions).
-
#get_transfers_with_http_info(opts = {}) ⇒ Array<(GetTransfersResponse, Integer, Hash)>
List transfers Returns a paginated list of transfers (payouts/dispersions).
-
#initialize(api_client = ApiClient.default) ⇒ TransfersApi
constructor
A new instance of TransfersApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ TransfersApi
Returns a new instance of TransfersApi.
19 20 21 |
# File 'lib/digital_femsa/api/transfers_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/digital_femsa/api/transfers_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_transfer(id, opts = {}) ⇒ TransferResponse
Get transfer Retrieves the details of a transfer by its ID.
29 30 31 32 |
# File 'lib/digital_femsa/api/transfers_api.rb', line 29 def get_transfer(id, opts = {}) data, _status_code, _headers = get_transfer_with_http_info(id, opts) data end |
#get_transfer_with_http_info(id, opts = {}) ⇒ Array<(TransferResponse, Integer, Hash)>
Get transfer Retrieves the details of a transfer by its ID.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/digital_femsa/api/transfers_api.rb', line 41 def get_transfer_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TransfersApi.get_transfer ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling TransfersApi.get_transfer" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/transfers/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TransferResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"TransfersApi.get_transfer", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TransfersApi#get_transfer\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_transfers(opts = {}) ⇒ GetTransfersResponse
List transfers Returns a paginated list of transfers (payouts/dispersions). A transfer represents a payout of funds to the merchant (where the money is sent and the payout status). Transfers typically aggregate multiple transactions. If you need movement-level details (amount/fee/net per operation) or to reconcile charges, use GET /transactions.
105 106 107 108 |
# File 'lib/digital_femsa/api/transfers_api.rb', line 105 def get_transfers(opts = {}) data, _status_code, _headers = get_transfers_with_http_info(opts) data end |
#get_transfers_with_http_info(opts = {}) ⇒ Array<(GetTransfersResponse, Integer, Hash)>
List transfers Returns a paginated list of transfers (payouts/dispersions). A transfer represents a payout of funds to the merchant (where the money is sent and the payout status). Transfers typically aggregate multiple transactions. If you need movement-level details (amount/fee/net per operation) or to reconcile charges, use GET /transactions.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/digital_femsa/api/transfers_api.rb', line 120 def get_transfers_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TransfersApi.get_transfers ...' end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 250 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling TransfersApi.get_transfers, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling TransfersApi.get_transfers, must be greater than or equal to 1.' end # resource path local_var_path = '/transfers' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'next'] = opts[:'_next'] if !opts[:'_next'].nil? query_params[:'previous'] = opts[:'previous'] if !opts[:'previous'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetTransfersResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"TransfersApi.get_transfers", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TransfersApi#get_transfers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |