Class: DigitalFemsa::WebhookKeysApi
- Inherits:
-
Object
- Object
- DigitalFemsa::WebhookKeysApi
- Defined in:
- lib/digital_femsa/api/webhook_keys_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_webhook_key(opts = {}) ⇒ WebhookKeyCreateResponse
Create Webhook Key Creates a new webhook signing key for the current company.
-
#create_webhook_key_with_http_info(opts = {}) ⇒ Array<(WebhookKeyCreateResponse, Integer, Hash)>
Create Webhook Key Creates a new webhook signing key for the current company.
-
#delete_webhook_key(id, opts = {}) ⇒ WebhookKeyDeleteResponse
Delete webhook key Deletes a webhook signing key.
-
#delete_webhook_key_with_http_info(id, opts = {}) ⇒ Array<(WebhookKeyDeleteResponse, Integer, Hash)>
Delete webhook key Deletes a webhook signing key.
-
#get_webhook_key(id, opts = {}) ⇒ WebhookKeyResponse
Get webhook key Retrieves the details of a webhook signing key by its ID.
-
#get_webhook_key_with_http_info(id, opts = {}) ⇒ Array<(WebhookKeyResponse, Integer, Hash)>
Get webhook key Retrieves the details of a webhook signing key by its ID.
-
#get_webhook_keys(opts = {}) ⇒ GetWebhookKeysResponse
Get List of Webhook Keys Consume the list of webhook keys you have.
-
#get_webhook_keys_with_http_info(opts = {}) ⇒ Array<(GetWebhookKeysResponse, Integer, Hash)>
Get List of Webhook Keys Consume the list of webhook keys you have.
-
#initialize(api_client = ApiClient.default) ⇒ WebhookKeysApi
constructor
A new instance of WebhookKeysApi.
-
#update_webhook_key(id, opts = {}) ⇒ WebhookKeyResponse
Update webhook key Activates or deactivates an existing webhook signing key.
-
#update_webhook_key_with_http_info(id, opts = {}) ⇒ Array<(WebhookKeyResponse, Integer, Hash)>
Update webhook key Activates or deactivates an existing webhook signing key.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WebhookKeysApi
Returns a new instance of WebhookKeysApi.
19 20 21 |
# File 'lib/digital_femsa/api/webhook_keys_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/digital_femsa/api/webhook_keys_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_webhook_key(opts = {}) ⇒ WebhookKeyCreateResponse
Create Webhook Key Creates a new webhook signing key for the current company.
28 29 30 31 |
# File 'lib/digital_femsa/api/webhook_keys_api.rb', line 28 def create_webhook_key(opts = {}) data, _status_code, _headers = create_webhook_key_with_http_info(opts) data end |
#create_webhook_key_with_http_info(opts = {}) ⇒ Array<(WebhookKeyCreateResponse, Integer, Hash)>
Create Webhook Key Creates a new webhook signing key for the current company.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/digital_femsa/api/webhook_keys_api.rb', line 39 def create_webhook_key_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhookKeysApi.create_webhook_key ...' end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/webhook_keys' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'webhook_key_request']) # return_type return_type = opts[:debug_return_type] || 'WebhookKeyCreateResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhookKeysApi.create_webhook_key", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhookKeysApi#create_webhook_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_webhook_key(id, opts = {}) ⇒ WebhookKeyDeleteResponse
Delete webhook key Deletes a webhook signing key.
99 100 101 102 |
# File 'lib/digital_femsa/api/webhook_keys_api.rb', line 99 def delete_webhook_key(id, opts = {}) data, _status_code, _headers = delete_webhook_key_with_http_info(id, opts) data end |
#delete_webhook_key_with_http_info(id, opts = {}) ⇒ Array<(WebhookKeyDeleteResponse, Integer, Hash)>
Delete webhook key Deletes a webhook signing key.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/digital_femsa/api/webhook_keys_api.rb', line 110 def delete_webhook_key_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhookKeysApi.delete_webhook_key ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling WebhookKeysApi.delete_webhook_key" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/webhook_keys/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WebhookKeyDeleteResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhookKeysApi.delete_webhook_key", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhookKeysApi#delete_webhook_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_webhook_key(id, opts = {}) ⇒ WebhookKeyResponse
Get webhook key Retrieves the details of a webhook signing key by its ID.
170 171 172 173 |
# File 'lib/digital_femsa/api/webhook_keys_api.rb', line 170 def get_webhook_key(id, opts = {}) data, _status_code, _headers = get_webhook_key_with_http_info(id, opts) data end |
#get_webhook_key_with_http_info(id, opts = {}) ⇒ Array<(WebhookKeyResponse, Integer, Hash)>
Get webhook key Retrieves the details of a webhook signing key by its ID.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/digital_femsa/api/webhook_keys_api.rb', line 182 def get_webhook_key_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhookKeysApi.get_webhook_key ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling WebhookKeysApi.get_webhook_key" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/webhook_keys/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WebhookKeyResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhookKeysApi.get_webhook_key", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhookKeysApi#get_webhook_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_webhook_keys(opts = {}) ⇒ GetWebhookKeysResponse
Get List of Webhook Keys Consume the list of webhook keys you have
246 247 248 249 |
# File 'lib/digital_femsa/api/webhook_keys_api.rb', line 246 def get_webhook_keys(opts = {}) data, _status_code, _headers = get_webhook_keys_with_http_info(opts) data end |
#get_webhook_keys_with_http_info(opts = {}) ⇒ Array<(GetWebhookKeysResponse, Integer, Hash)>
Get List of Webhook Keys Consume the list of webhook keys you have
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/digital_femsa/api/webhook_keys_api.rb', line 261 def get_webhook_keys_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhookKeysApi.get_webhook_keys ...' end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 250 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling WebhookKeysApi.get_webhook_keys, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling WebhookKeysApi.get_webhook_keys, must be greater than or equal to 1.' end # resource path local_var_path = '/webhook_keys' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'next'] = opts[:'_next'] if !opts[:'_next'].nil? query_params[:'previous'] = opts[:'previous'] if !opts[:'previous'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetWebhookKeysResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhookKeysApi.get_webhook_keys", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhookKeysApi#get_webhook_keys\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_webhook_key(id, opts = {}) ⇒ WebhookKeyResponse
Update webhook key Activates or deactivates an existing webhook signing key.
330 331 332 333 |
# File 'lib/digital_femsa/api/webhook_keys_api.rb', line 330 def update_webhook_key(id, opts = {}) data, _status_code, _headers = update_webhook_key_with_http_info(id, opts) data end |
#update_webhook_key_with_http_info(id, opts = {}) ⇒ Array<(WebhookKeyResponse, Integer, Hash)>
Update webhook key Activates or deactivates an existing webhook signing key.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/digital_femsa/api/webhook_keys_api.rb', line 342 def update_webhook_key_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhookKeysApi.update_webhook_key ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling WebhookKeysApi.update_webhook_key" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/webhook_keys/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'webhook_key_update_request']) # return_type return_type = opts[:debug_return_type] || 'WebhookKeyResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhookKeysApi.update_webhook_key", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhookKeysApi#update_webhook_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |