Class: DigitalFemsa::WebhooksApi
- Inherits:
-
Object
- Object
- DigitalFemsa::WebhooksApi
- Defined in:
- lib/digital_femsa/api/webhooks_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_webhook(webhook_request, opts = {}) ⇒ WebhookResponse
Create Webhook What we do at Femsa translates into events.
-
#create_webhook_with_http_info(webhook_request, opts = {}) ⇒ Array<(WebhookResponse, Integer, Hash)>
Create Webhook What we do at Femsa translates into events.
-
#delete_webhook(id, opts = {}) ⇒ WebhookResponse
Delete webhook Deletes a webhook.
-
#delete_webhook_with_http_info(id, opts = {}) ⇒ Array<(WebhookResponse, Integer, Hash)>
Delete webhook Deletes a webhook.
-
#get_webhook(id, opts = {}) ⇒ WebhookResponse
Get webhook Retrieves the details of a webhook by its ID.
-
#get_webhook_with_http_info(id, opts = {}) ⇒ Array<(WebhookResponse, Integer, Hash)>
Get webhook Retrieves the details of a webhook by its ID.
-
#get_webhooks(opts = {}) ⇒ GetWebhooksResponse
Get List of Webhooks Consume the list of webhooks you have, each environment supports 10 webhooks (For production and testing).
-
#get_webhooks_with_http_info(opts = {}) ⇒ Array<(GetWebhooksResponse, Integer, Hash)>
Get List of Webhooks Consume the list of webhooks you have, each environment supports 10 webhooks (For production and testing).
-
#initialize(api_client = ApiClient.default) ⇒ WebhooksApi
constructor
A new instance of WebhooksApi.
-
#test_webhook(id, opts = {}) ⇒ WebhookResponse
Test webhook Sends a test event to the specified webhook to verify it can receive events.
-
#test_webhook_with_http_info(id, opts = {}) ⇒ Array<(WebhookResponse, Integer, Hash)>
Test webhook Sends a test event to the specified webhook to verify it can receive events.
-
#update_webhook(id, webhook_update_request, opts = {}) ⇒ WebhookResponse
Update webhook Updates an existing webhook.
-
#update_webhook_with_http_info(id, webhook_update_request, opts = {}) ⇒ Array<(WebhookResponse, Integer, Hash)>
Update webhook Updates an existing webhook.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WebhooksApi
Returns a new instance of WebhooksApi.
19 20 21 |
# File 'lib/digital_femsa/api/webhooks_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/digital_femsa/api/webhooks_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_webhook(webhook_request, opts = {}) ⇒ WebhookResponse
Create Webhook What we do at Femsa translates into events. For example, an event of interest to us occurs at the time a payment is successfully processed. At that moment we will be interested in doing several things: Send an email to the buyer, generate an invoice, start the process of shipping the product, etc.
28 29 30 31 |
# File 'lib/digital_femsa/api/webhooks_api.rb', line 28 def create_webhook(webhook_request, opts = {}) data, _status_code, _headers = create_webhook_with_http_info(webhook_request, opts) data end |
#create_webhook_with_http_info(webhook_request, opts = {}) ⇒ Array<(WebhookResponse, Integer, Hash)>
Create Webhook What we do at Femsa translates into events. For example, an event of interest to us occurs at the time a payment is successfully processed. At that moment we will be interested in doing several things: Send an email to the buyer, generate an invoice, start the process of shipping the product, etc.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/digital_femsa/api/webhooks_api.rb', line 39 def create_webhook_with_http_info(webhook_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.create_webhook ...' end # verify the required parameter 'webhook_request' is set if @api_client.config.client_side_validation && webhook_request.nil? fail ArgumentError, "Missing the required parameter 'webhook_request' when calling WebhooksApi.create_webhook" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/webhooks' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(webhook_request) # return_type return_type = opts[:debug_return_type] || 'WebhookResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.create_webhook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#create_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_webhook(id, opts = {}) ⇒ WebhookResponse
Delete webhook Deletes a webhook.
103 104 105 106 |
# File 'lib/digital_femsa/api/webhooks_api.rb', line 103 def delete_webhook(id, opts = {}) data, _status_code, _headers = delete_webhook_with_http_info(id, opts) data end |
#delete_webhook_with_http_info(id, opts = {}) ⇒ Array<(WebhookResponse, Integer, Hash)>
Delete webhook Deletes a webhook.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/digital_femsa/api/webhooks_api.rb', line 114 def delete_webhook_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.delete_webhook ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling WebhooksApi.delete_webhook" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/webhooks/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WebhookResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.delete_webhook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#delete_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_webhook(id, opts = {}) ⇒ WebhookResponse
Get webhook Retrieves the details of a webhook by its ID.
174 175 176 177 |
# File 'lib/digital_femsa/api/webhooks_api.rb', line 174 def get_webhook(id, opts = {}) data, _status_code, _headers = get_webhook_with_http_info(id, opts) data end |
#get_webhook_with_http_info(id, opts = {}) ⇒ Array<(WebhookResponse, Integer, Hash)>
Get webhook Retrieves the details of a webhook by its ID.
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/digital_femsa/api/webhooks_api.rb', line 186 def get_webhook_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.get_webhook ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling WebhooksApi.get_webhook" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/webhooks/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WebhookResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.get_webhook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#get_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_webhooks(opts = {}) ⇒ GetWebhooksResponse
Get List of Webhooks Consume the list of webhooks you have, each environment supports 10 webhooks (For production and testing)
251 252 253 254 |
# File 'lib/digital_femsa/api/webhooks_api.rb', line 251 def get_webhooks(opts = {}) data, _status_code, _headers = get_webhooks_with_http_info(opts) data end |
#get_webhooks_with_http_info(opts = {}) ⇒ Array<(GetWebhooksResponse, Integer, Hash)>
Get List of Webhooks Consume the list of webhooks you have, each environment supports 10 webhooks (For production and testing)
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/digital_femsa/api/webhooks_api.rb', line 267 def get_webhooks_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.get_webhooks ...' end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 250 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling WebhooksApi.get_webhooks, must be smaller than or equal to 250.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling WebhooksApi.get_webhooks, must be greater than or equal to 1.' end # resource path local_var_path = '/webhooks' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'url'] = opts[:'url'] if !opts[:'url'].nil? query_params[:'next'] = opts[:'_next'] if !opts[:'_next'].nil? query_params[:'previous'] = opts[:'previous'] if !opts[:'previous'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetWebhooksResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.get_webhooks", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#get_webhooks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#test_webhook(id, opts = {}) ⇒ WebhookResponse
Test webhook Sends a test event to the specified webhook to verify it can receive events.
336 337 338 339 |
# File 'lib/digital_femsa/api/webhooks_api.rb', line 336 def test_webhook(id, opts = {}) data, _status_code, _headers = test_webhook_with_http_info(id, opts) data end |
#test_webhook_with_http_info(id, opts = {}) ⇒ Array<(WebhookResponse, Integer, Hash)>
Test webhook Sends a test event to the specified webhook to verify it can receive events.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/digital_femsa/api/webhooks_api.rb', line 347 def test_webhook_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.test_webhook ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling WebhooksApi.test_webhook" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/webhooks/{id}/test'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WebhookResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.test_webhook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#test_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_webhook(id, webhook_update_request, opts = {}) ⇒ WebhookResponse
Update webhook Updates an existing webhook.
408 409 410 411 |
# File 'lib/digital_femsa/api/webhooks_api.rb', line 408 def update_webhook(id, webhook_update_request, opts = {}) data, _status_code, _headers = update_webhook_with_http_info(id, webhook_update_request, opts) data end |
#update_webhook_with_http_info(id, webhook_update_request, opts = {}) ⇒ Array<(WebhookResponse, Integer, Hash)>
Update webhook Updates an existing webhook.
421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'lib/digital_femsa/api/webhooks_api.rb', line 421 def update_webhook_with_http_info(id, webhook_update_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.update_webhook ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling WebhooksApi.update_webhook" end # verify the required parameter 'webhook_update_request' is set if @api_client.config.client_side_validation && webhook_update_request.nil? fail ArgumentError, "Missing the required parameter 'webhook_update_request' when calling WebhooksApi.update_webhook" end allowable_values = ["es", "en"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/webhooks/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.app-v2.1.0+json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'X-Child-Company-Id'] = opts[:'x_child_company_id'] if !opts[:'x_child_company_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(webhook_update_request) # return_type return_type = opts[:debug_return_type] || 'WebhookResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.update_webhook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#update_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |