Class: DigitalFemsa::OrderRequest
- Inherits:
-
Object
- Object
- DigitalFemsa::OrderRequest
- Defined in:
- lib/digital_femsa/models/order_request.rb
Overview
a order
Instance Attribute Summary collapse
-
#charges ⇒ Object
List of [charges](developers.digitalfemsa.io/reference/orderscreatecharge) that are applied to the order.
-
#checkout ⇒ Object
Returns the value of attribute checkout.
-
#currency ⇒ Object
Currency with which the payment will be made.
-
#customer_info ⇒ Object
Returns the value of attribute customer_info.
-
#discount_lines ⇒ Object
List of [discounts](developers.digitalfemsa.io/reference/orderscreatediscountline) that are applied to the order.
-
#fiscal_entity ⇒ Object
Returns the value of attribute fiscal_entity.
-
#line_items ⇒ Object
List of [products](developers.digitalfemsa.io/reference/orderscreateproduct) that are sold in the order.
-
#metadata ⇒ Object
Arbitrary key-value data that you can attach to the order for your internal use (e.g. ‘customer_segment`, `sales_channel`, `internal_order_id`).
-
#needs_shipping_contact ⇒ Object
Allows you to fill out the shipping information at checkout.
-
#processing_mode ⇒ Object
Indicates the processing mode for the order, either ecommerce, recurrent or validation.
-
#shipping_contact ⇒ Object
Returns the value of attribute shipping_contact.
-
#shipping_lines ⇒ Object
List of [shipping costs](developers.digitalfemsa.io/reference/orderscreateshipping).
-
#tax_lines ⇒ Object
List of [taxes](developers.digitalfemsa.io/reference/orderscreatetaxes) that are applied to the order.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrderRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ OrderRequest
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/digital_femsa/models/order_request.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DigitalFemsa::OrderRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DigitalFemsa::OrderRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'currency') self.currency = attributes[:'currency'] else self.currency = nil end if attributes.key?(:'customer_info') self.customer_info = attributes[:'customer_info'] else self.customer_info = nil end if attributes.key?(:'line_items') if (value = attributes[:'line_items']).is_a?(Array) self.line_items = value end else self.line_items = nil end if attributes.key?(:'charges') if (value = attributes[:'charges']).is_a?(Array) self.charges = value end end if attributes.key?(:'checkout') self.checkout = attributes[:'checkout'] end if attributes.key?(:'discount_lines') if (value = attributes[:'discount_lines']).is_a?(Array) self.discount_lines = value end end if attributes.key?(:'tax_lines') if (value = attributes[:'tax_lines']).is_a?(Array) self.tax_lines = value end end if attributes.key?(:'needs_shipping_contact') self.needs_shipping_contact = attributes[:'needs_shipping_contact'] end if attributes.key?(:'shipping_contact') self.shipping_contact = attributes[:'shipping_contact'] end if attributes.key?(:'shipping_lines') if (value = attributes[:'shipping_lines']).is_a?(Array) self.shipping_lines = value end end if attributes.key?(:'fiscal_entity') self.fiscal_entity = attributes[:'fiscal_entity'] end if attributes.key?(:'processing_mode') self.processing_mode = attributes[:'processing_mode'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end end |
Instance Attribute Details
#charges ⇒ Object
List of [charges](developers.digitalfemsa.io/reference/orderscreatecharge) that are applied to the order
28 29 30 |
# File 'lib/digital_femsa/models/order_request.rb', line 28 def charges @charges end |
#checkout ⇒ Object
Returns the value of attribute checkout.
30 31 32 |
# File 'lib/digital_femsa/models/order_request.rb', line 30 def checkout @checkout end |
#currency ⇒ Object
Currency with which the payment will be made.
20 21 22 |
# File 'lib/digital_femsa/models/order_request.rb', line 20 def currency @currency end |
#customer_info ⇒ Object
Returns the value of attribute customer_info.
22 23 24 |
# File 'lib/digital_femsa/models/order_request.rb', line 22 def customer_info @customer_info end |
#discount_lines ⇒ Object
List of [discounts](developers.digitalfemsa.io/reference/orderscreatediscountline) that are applied to the order. You must have at least one discount.
33 34 35 |
# File 'lib/digital_femsa/models/order_request.rb', line 33 def discount_lines @discount_lines end |
#fiscal_entity ⇒ Object
Returns the value of attribute fiscal_entity.
46 47 48 |
# File 'lib/digital_femsa/models/order_request.rb', line 46 def fiscal_entity @fiscal_entity end |
#line_items ⇒ Object
List of [products](developers.digitalfemsa.io/reference/orderscreateproduct) that are sold in the order. You must have at least one product.
25 26 27 |
# File 'lib/digital_femsa/models/order_request.rb', line 25 def line_items @line_items end |
#metadata ⇒ Object
Arbitrary key-value data that you can attach to the order for your internal use (e.g. ‘customer_segment`, `sales_channel`, `internal_order_id`). It is not used for payment processing or fraud decisions. Keys should be strings; values can be any JSON value.
52 53 54 |
# File 'lib/digital_femsa/models/order_request.rb', line 52 def @metadata end |
#needs_shipping_contact ⇒ Object
Allows you to fill out the shipping information at checkout
39 40 41 |
# File 'lib/digital_femsa/models/order_request.rb', line 39 def needs_shipping_contact @needs_shipping_contact end |
#processing_mode ⇒ Object
Indicates the processing mode for the order, either ecommerce, recurrent or validation.
49 50 51 |
# File 'lib/digital_femsa/models/order_request.rb', line 49 def processing_mode @processing_mode end |
#shipping_contact ⇒ Object
Returns the value of attribute shipping_contact.
41 42 43 |
# File 'lib/digital_femsa/models/order_request.rb', line 41 def shipping_contact @shipping_contact end |
#shipping_lines ⇒ Object
List of [shipping costs](developers.digitalfemsa.io/reference/orderscreateshipping). If the online store offers digital products.
44 45 46 |
# File 'lib/digital_femsa/models/order_request.rb', line 44 def shipping_lines @shipping_lines end |
#tax_lines ⇒ Object
List of [taxes](developers.digitalfemsa.io/reference/orderscreatetaxes) that are applied to the order.
36 37 38 |
# File 'lib/digital_femsa/models/order_request.rb', line 36 def tax_lines @tax_lines end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/digital_femsa/models/order_request.rb', line 316 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = DigitalFemsa.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/digital_femsa/models/order_request.rb', line 74 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/digital_femsa/models/order_request.rb', line 55 def self.attribute_map { :'currency' => :'currency', :'customer_info' => :'customer_info', :'line_items' => :'line_items', :'charges' => :'charges', :'checkout' => :'checkout', :'discount_lines' => :'discount_lines', :'tax_lines' => :'tax_lines', :'needs_shipping_contact' => :'needs_shipping_contact', :'shipping_contact' => :'shipping_contact', :'shipping_lines' => :'shipping_lines', :'fiscal_entity' => :'fiscal_entity', :'processing_mode' => :'processing_mode', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/digital_femsa/models/order_request.rb', line 292 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/digital_femsa/models/order_request.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/digital_femsa/models/order_request.rb', line 79 def self.openapi_types { :'currency' => :'String', :'customer_info' => :'OrderRequestCustomerInfo', :'line_items' => :'Array<Product>', :'charges' => :'Array<ChargeRequest>', :'checkout' => :'CheckoutRequest', :'discount_lines' => :'Array<OrderDiscountLinesRequest>', :'tax_lines' => :'Array<OrderTaxRequest>', :'needs_shipping_contact' => :'Boolean', :'shipping_contact' => :'CustomerShippingContacts', :'shipping_lines' => :'Array<ShippingRequest>', :'fiscal_entity' => :'OrderFiscalEntityRequest', :'processing_mode' => :'String', :'metadata' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/digital_femsa/models/order_request.rb', line 259 def ==(o) return true if self.equal?(o) self.class == o.class && currency == o.currency && customer_info == o.customer_info && line_items == o.line_items && charges == o.charges && checkout == o.checkout && discount_lines == o.discount_lines && tax_lines == o.tax_lines && needs_shipping_contact == o.needs_shipping_contact && shipping_contact == o.shipping_contact && shipping_lines == o.shipping_lines && fiscal_entity == o.fiscal_entity && processing_mode == o.processing_mode && == o. end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/digital_femsa/models/order_request.rb', line 387 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
279 280 281 |
# File 'lib/digital_femsa/models/order_request.rb', line 279 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
285 286 287 |
# File 'lib/digital_femsa/models/order_request.rb', line 285 def hash [currency, customer_info, line_items, charges, checkout, discount_lines, tax_lines, needs_shipping_contact, shipping_contact, shipping_lines, fiscal_entity, processing_mode, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/digital_femsa/models/order_request.rb', line 191 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if @currency.to_s.length > 3 invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.') end if @customer_info.nil? invalid_properties.push('invalid value for "customer_info", customer_info cannot be nil.') end if @line_items.nil? invalid_properties.push('invalid value for "line_items", line_items cannot be nil.') end if !@metadata.nil? && @metadata.length > 100 invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
363 364 365 |
# File 'lib/digital_femsa/models/order_request.rb', line 363 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/digital_femsa/models/order_request.rb', line 369 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
357 358 359 |
# File 'lib/digital_femsa/models/order_request.rb', line 357 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
219 220 221 222 223 224 225 226 227 |
# File 'lib/digital_femsa/models/order_request.rb', line 219 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @currency.nil? return false if @currency.to_s.length > 3 return false if @customer_info.nil? return false if @line_items.nil? return false if !@metadata.nil? && @metadata.length > 100 true end |