Class: DigitalFemsa::OrderResponse
- Inherits:
-
Object
- Object
- DigitalFemsa::OrderResponse
- Defined in:
- lib/digital_femsa/models/order_response.rb
Overview
Order model. Some nested resources are returned as list previews (for example: ‘charges`, `line_items`), and may be `null` depending on the request/context. The `checkout` field is only present when the order is linked to a checkout (`channel.checkout_request_id`).
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
Returns the value of attribute amount.
-
#amount_refunded ⇒ Object
Returns the value of attribute amount_refunded.
-
#channel ⇒ Object
Returns the value of attribute channel.
-
#charges ⇒ Object
Returns the value of attribute charges.
-
#checkout ⇒ Object
Returns the value of attribute checkout.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#customer_info ⇒ Object
Returns the value of attribute customer_info.
-
#discount_lines ⇒ Object
Returns the value of attribute discount_lines.
-
#fiscal_entity ⇒ Object
Returns the value of attribute fiscal_entity.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_refundable ⇒ Object
Indicates whether the order is currently refundable.
-
#line_items ⇒ Object
Returns the value of attribute line_items.
-
#livemode ⇒ Object
Returns the value of attribute livemode.
-
#metadata ⇒ Object
Metadata attached to the order.
-
#object ⇒ Object
Returns the value of attribute object.
-
#partial_reference ⇒ Object
Partial reference information (when applicable).
-
#payment_status ⇒ Object
Current payment status of the order.
-
#payments_info ⇒ Object
Additional payment information (when available).
-
#shipping_contact ⇒ Object
Returns the value of attribute shipping_contact.
-
#split_payment ⇒ Object
Indicates whether the order uses split payments (when available/configured).
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrderResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ OrderResponse
Initializes the object
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/digital_femsa/models/order_response.rb', line 167 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DigitalFemsa::OrderResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DigitalFemsa::OrderResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'object') self.object = attributes[:'object'] end if attributes.key?(:'livemode') self.livemode = attributes[:'livemode'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'payment_status') self.payment_status = attributes[:'payment_status'] end if attributes.key?(:'amount_refunded') self.amount_refunded = attributes[:'amount_refunded'] end if attributes.key?(:'split_payment') self.split_payment = attributes[:'split_payment'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'is_refundable') self.is_refundable = attributes[:'is_refundable'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'customer_info') self.customer_info = attributes[:'customer_info'] end if attributes.key?(:'shipping_contact') self.shipping_contact = attributes[:'shipping_contact'] end if attributes.key?(:'channel') self.channel = attributes[:'channel'] end if attributes.key?(:'fiscal_entity') self.fiscal_entity = attributes[:'fiscal_entity'] end if attributes.key?(:'checkout') self.checkout = attributes[:'checkout'] end if attributes.key?(:'line_items') self.line_items = attributes[:'line_items'] end if attributes.key?(:'discount_lines') self.discount_lines = attributes[:'discount_lines'] end if attributes.key?(:'charges') self.charges = attributes[:'charges'] end if attributes.key?(:'partial_reference') if (value = attributes[:'partial_reference']).is_a?(Hash) self.partial_reference = value end end if attributes.key?(:'payments_info') if (value = attributes[:'payments_info']).is_a?(Hash) self.payments_info = value end end end |
Instance Attribute Details
#amount ⇒ Object
Returns the value of attribute amount.
25 26 27 |
# File 'lib/digital_femsa/models/order_response.rb', line 25 def amount @amount end |
#amount_refunded ⇒ Object
Returns the value of attribute amount_refunded.
32 33 34 |
# File 'lib/digital_femsa/models/order_response.rb', line 32 def amount_refunded @amount_refunded end |
#channel ⇒ Object
Returns the value of attribute channel.
51 52 53 |
# File 'lib/digital_femsa/models/order_response.rb', line 51 def channel @channel end |
#charges ⇒ Object
Returns the value of attribute charges.
61 62 63 |
# File 'lib/digital_femsa/models/order_response.rb', line 61 def charges @charges end |
#checkout ⇒ Object
Returns the value of attribute checkout.
55 56 57 |
# File 'lib/digital_femsa/models/order_response.rb', line 55 def checkout @checkout end |
#created_at ⇒ Object
Returns the value of attribute created_at.
43 44 45 |
# File 'lib/digital_femsa/models/order_response.rb', line 43 def created_at @created_at end |
#currency ⇒ Object
Returns the value of attribute currency.
27 28 29 |
# File 'lib/digital_femsa/models/order_response.rb', line 27 def currency @currency end |
#customer_info ⇒ Object
Returns the value of attribute customer_info.
47 48 49 |
# File 'lib/digital_femsa/models/order_response.rb', line 47 def customer_info @customer_info end |
#discount_lines ⇒ Object
Returns the value of attribute discount_lines.
59 60 61 |
# File 'lib/digital_femsa/models/order_response.rb', line 59 def discount_lines @discount_lines end |
#fiscal_entity ⇒ Object
Returns the value of attribute fiscal_entity.
53 54 55 |
# File 'lib/digital_femsa/models/order_response.rb', line 53 def fiscal_entity @fiscal_entity end |
#id ⇒ Object
Returns the value of attribute id.
19 20 21 |
# File 'lib/digital_femsa/models/order_response.rb', line 19 def id @id end |
#is_refundable ⇒ Object
Indicates whether the order is currently refundable.
41 42 43 |
# File 'lib/digital_femsa/models/order_response.rb', line 41 def is_refundable @is_refundable end |
#line_items ⇒ Object
Returns the value of attribute line_items.
57 58 59 |
# File 'lib/digital_femsa/models/order_response.rb', line 57 def line_items @line_items end |
#livemode ⇒ Object
Returns the value of attribute livemode.
23 24 25 |
# File 'lib/digital_femsa/models/order_response.rb', line 23 def livemode @livemode end |
#metadata ⇒ Object
Metadata attached to the order.
38 39 40 |
# File 'lib/digital_femsa/models/order_response.rb', line 38 def @metadata end |
#object ⇒ Object
Returns the value of attribute object.
21 22 23 |
# File 'lib/digital_femsa/models/order_response.rb', line 21 def object @object end |
#partial_reference ⇒ Object
Partial reference information (when applicable). Structure may vary depending on the payment flow.
64 65 66 |
# File 'lib/digital_femsa/models/order_response.rb', line 64 def partial_reference @partial_reference end |
#payment_status ⇒ Object
Current payment status of the order. It can be ‘null` for orders without payment information yet.
30 31 32 |
# File 'lib/digital_femsa/models/order_response.rb', line 30 def payment_status @payment_status end |
#payments_info ⇒ Object
Additional payment information (when available). Structure may vary.
67 68 69 |
# File 'lib/digital_femsa/models/order_response.rb', line 67 def payments_info @payments_info end |
#shipping_contact ⇒ Object
Returns the value of attribute shipping_contact.
49 50 51 |
# File 'lib/digital_femsa/models/order_response.rb', line 49 def shipping_contact @shipping_contact end |
#split_payment ⇒ Object
Indicates whether the order uses split payments (when available/configured).
35 36 37 |
# File 'lib/digital_femsa/models/order_response.rb', line 35 def split_payment @split_payment end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
45 46 47 |
# File 'lib/digital_femsa/models/order_response.rb', line 45 def updated_at @updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/digital_femsa/models/order_response.rb', line 408 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = DigitalFemsa.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
120 121 122 |
# File 'lib/digital_femsa/models/order_response.rb', line 120 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/digital_femsa/models/order_response.rb', line 92 def self.attribute_map { :'id' => :'id', :'object' => :'object', :'livemode' => :'livemode', :'amount' => :'amount', :'currency' => :'currency', :'payment_status' => :'payment_status', :'amount_refunded' => :'amount_refunded', :'split_payment' => :'split_payment', :'metadata' => :'metadata', :'is_refundable' => :'is_refundable', :'created_at' => :'created_at', :'updated_at' => :'updated_at', :'customer_info' => :'customer_info', :'shipping_contact' => :'shipping_contact', :'channel' => :'channel', :'fiscal_entity' => :'fiscal_entity', :'checkout' => :'checkout', :'line_items' => :'line_items', :'discount_lines' => :'discount_lines', :'charges' => :'charges', :'partial_reference' => :'partial_reference', :'payments_info' => :'payments_info' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/digital_femsa/models/order_response.rb', line 384 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/digital_femsa/models/order_response.rb', line 153 def self.openapi_nullable Set.new([ :'payment_status', :'split_payment', :'shipping_contact', :'channel', :'fiscal_entity', :'partial_reference', :'payments_info' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/digital_femsa/models/order_response.rb', line 125 def self.openapi_types { :'id' => :'String', :'object' => :'String', :'livemode' => :'Boolean', :'amount' => :'Integer', :'currency' => :'String', :'payment_status' => :'String', :'amount_refunded' => :'Integer', :'split_payment' => :'Boolean', :'metadata' => :'Hash<String, Object>', :'is_refundable' => :'Boolean', :'created_at' => :'Integer', :'updated_at' => :'Integer', :'customer_info' => :'OrderResponseCustomerInfo', :'shipping_contact' => :'OrderResponseShippingContact', :'channel' => :'OrderResponseChannel', :'fiscal_entity' => :'OrderFiscalEntityResponse', :'checkout' => :'OrderResponseCheckout', :'line_items' => :'OrderResponseProducts', :'discount_lines' => :'OrderResponseDiscountLines', :'charges' => :'OrderResponseCharges', :'partial_reference' => :'Hash<String, Object>', :'payments_info' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/digital_femsa/models/order_response.rb', line 342 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && object == o.object && livemode == o.livemode && amount == o.amount && currency == o.currency && payment_status == o.payment_status && amount_refunded == o.amount_refunded && split_payment == o.split_payment && == o. && is_refundable == o.is_refundable && created_at == o.created_at && updated_at == o.updated_at && customer_info == o.customer_info && shipping_contact == o.shipping_contact && channel == o.channel && fiscal_entity == o.fiscal_entity && checkout == o.checkout && line_items == o.line_items && discount_lines == o.discount_lines && charges == o.charges && partial_reference == o.partial_reference && payments_info == o.payments_info end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
479 480 481 482 483 484 485 486 487 488 489 490 491 |
# File 'lib/digital_femsa/models/order_response.rb', line 479 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
371 372 373 |
# File 'lib/digital_femsa/models/order_response.rb', line 371 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
377 378 379 |
# File 'lib/digital_femsa/models/order_response.rb', line 377 def hash [id, object, livemode, amount, currency, payment_status, amount_refunded, split_payment, , is_refundable, created_at, updated_at, customer_info, shipping_contact, channel, fiscal_entity, checkout, line_items, discount_lines, charges, partial_reference, payments_info].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/digital_femsa/models/order_response.rb', line 277 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@currency.nil? && @currency.to_s.length > 3 invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.') end if !@metadata.nil? && @metadata.length > 100 invalid_properties.push('invalid value for "metadata", number of items must be less than or equal to 100.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
455 456 457 |
# File 'lib/digital_femsa/models/order_response.rb', line 455 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
461 462 463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/digital_femsa/models/order_response.rb', line 461 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
449 450 451 |
# File 'lib/digital_femsa/models/order_response.rb', line 449 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
293 294 295 296 297 298 299 300 |
# File 'lib/digital_femsa/models/order_response.rb', line 293 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' object_validator = EnumAttributeValidator.new('String', ["order"]) return false unless object_validator.valid?(@object) return false if !@currency.nil? && @currency.to_s.length > 3 return false if !@metadata.nil? && @metadata.length > 100 true end |