Class: DigitalFemsa::TransactionResponse
- Inherits:
-
Object
- Object
- DigitalFemsa::TransactionResponse
- Defined in:
- lib/digital_femsa/models/transaction_response.rb
Overview
Transaction object.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount of the transaction.
-
#charge ⇒ Object
Charge ID associated with the transaction (present only if the transaction belongs to a charge).
-
#created_at ⇒ Object
Date and time of creation of the transaction in Unix format.
-
#currency ⇒ Object
The currency of the transaction.
-
#fee ⇒ Object
The amount to be deducted for taxes and commissions.
-
#formula ⇒ Object
Transaction fee formula identifier (if available).
-
#id ⇒ Object
Unique identifier of the transaction.
-
#livemode ⇒ Object
Indicates whether the transaction was created in live mode or test mode.
-
#net ⇒ Object
The net amount after deducting commissions and taxes.
-
#object ⇒ Object
Object name, which is transaction.
-
#status ⇒ Object
Code indicating transaction status.
-
#transfer ⇒ Object
Transfer ID associated with the transaction (present only if the transaction belongs to a transfer).
-
#transferred_at ⇒ Object
Date and time when the transaction was transferred, in Unix format.
-
#type ⇒ Object
Transaction type.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TransactionResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TransactionResponse
Initializes the object
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 140 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DigitalFemsa::TransactionResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DigitalFemsa::TransactionResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'object') self.object = attributes[:'object'] else self.object = nil end if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'fee') self.fee = attributes[:'fee'] else self.fee = nil end if attributes.key?(:'net') self.net = attributes[:'net'] else self.net = nil end if attributes.key?(:'currency') self.currency = attributes[:'currency'] else self.currency = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'livemode') self.livemode = attributes[:'livemode'] else self.livemode = nil end if attributes.key?(:'charge') self.charge = attributes[:'charge'] end if attributes.key?(:'transfer') self.transfer = attributes[:'transfer'] end if attributes.key?(:'transferred_at') self.transferred_at = attributes[:'transferred_at'] end if attributes.key?(:'formula') self.formula = attributes[:'formula'] end end |
Instance Attribute Details
#amount ⇒ Object
The amount of the transaction.
26 27 28 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 26 def amount @amount end |
#charge ⇒ Object
Charge ID associated with the transaction (present only if the transaction belongs to a charge).
50 51 52 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 50 def charge @charge end |
#created_at ⇒ Object
Date and time of creation of the transaction in Unix format.
44 45 46 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 44 def created_at @created_at end |
#currency ⇒ Object
The currency of the transaction. It uses the 3-letter code of ISO 4217.
35 36 37 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 35 def currency @currency end |
#fee ⇒ Object
The amount to be deducted for taxes and commissions.
29 30 31 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 29 def fee @fee end |
#formula ⇒ Object
Transaction fee formula identifier (if available).
59 60 61 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 59 def formula @formula end |
#id ⇒ Object
Unique identifier of the transaction.
20 21 22 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 20 def id @id end |
#livemode ⇒ Object
Indicates whether the transaction was created in live mode or test mode.
47 48 49 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 47 def livemode @livemode end |
#net ⇒ Object
The net amount after deducting commissions and taxes.
32 33 34 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 32 def net @net end |
#object ⇒ Object
Object name, which is transaction.
23 24 25 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 23 def object @object end |
#status ⇒ Object
Code indicating transaction status.
38 39 40 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 38 def status @status end |
#transfer ⇒ Object
Transfer ID associated with the transaction (present only if the transaction belongs to a transfer).
53 54 55 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 53 def transfer @transfer end |
#transferred_at ⇒ Object
Date and time when the transaction was transferred, in Unix format.
56 57 58 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 56 def transferred_at @transferred_at end |
#type ⇒ Object
Transaction type.
41 42 43 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 41 def type @type end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 398 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = DigitalFemsa.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
104 105 106 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 104 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 84 def self.attribute_map { :'id' => :'id', :'object' => :'object', :'amount' => :'amount', :'fee' => :'fee', :'net' => :'net', :'currency' => :'currency', :'status' => :'status', :'type' => :'type', :'created_at' => :'created_at', :'livemode' => :'livemode', :'charge' => :'charge', :'transfer' => :'transfer', :'transferred_at' => :'transferred_at', :'formula' => :'formula' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 374 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
129 130 131 132 133 134 135 136 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 129 def self.openapi_nullable Set.new([ :'charge', :'transfer', :'transferred_at', :'formula' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 109 def self.openapi_types { :'id' => :'String', :'object' => :'String', :'amount' => :'Integer', :'fee' => :'Integer', :'net' => :'Integer', :'currency' => :'String', :'status' => :'String', :'type' => :'String', :'created_at' => :'Integer', :'livemode' => :'Boolean', :'charge' => :'String', :'transfer' => :'String', :'transferred_at' => :'Integer', :'formula' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 340 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && object == o.object && amount == o.amount && fee == o.fee && net == o.net && currency == o.currency && status == o.status && type == o.type && created_at == o.created_at && livemode == o.livemode && charge == o.charge && transfer == o.transfer && transferred_at == o.transferred_at && formula == o.formula end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 469 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
361 362 363 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 361 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
367 368 369 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 367 def hash [id, object, amount, fee, net, currency, status, type, created_at, livemode, charge, transfer, transferred_at, formula].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 232 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @object.nil? invalid_properties.push('invalid value for "object", object cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @fee.nil? invalid_properties.push('invalid value for "fee", fee cannot be nil.') end if @net.nil? invalid_properties.push('invalid value for "net", net cannot be nil.') end if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if @currency.to_s.length > 3 invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @livemode.nil? invalid_properties.push('invalid value for "livemode", livemode cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
445 446 447 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 445 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 451 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
439 440 441 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 439 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/digital_femsa/models/transaction_response.rb', line 284 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @object.nil? return false if @amount.nil? return false if @fee.nil? return false if @net.nil? return false if @currency.nil? return false if @currency.to_s.length > 3 return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["unprocessed", "pending", "available", "owing", "paid_out", "on_hold", "retained", "voided"]) return false unless status_validator.valid?(@status) return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["capture", "capture_reversal", "liquidation", "liquidation_reversal", "payout", "payout_reversal", "refund", "refund_reversal", "rounding_adjustment", "transfer", "transferred", "retention", "temporary_retention", "cashout_retention", "cashout_confirmation", "cashout_cancelation", "autofund_capture"]) return false unless type_validator.valid?(@type) return false if @created_at.nil? return false if @livemode.nil? true end |